import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

class DYTitleWidget extends StatelessWidget {
  bool web;

  DYTitleWidget(this.web);

  @override
  Widget build(BuildContext context) {
    var dyLogo = "assets/dy.png";

    return Flex(
      direction: Axis.horizontal,
      children: [
        web
            ? Image.network(
                dyLogo,
                scale: 3,
              )
            : Expanded(child: Image.asset(dyLogo)),
        RichText(
          text: TextSpan(
              // text: Strings.docufy,
              // style: TextStyle(fontSize: 48, color: MyColors.dy_green),
              children: [
                TextSpan(
                    text: "Strings meetingrooms",
                    style: TextStyle(
                        fontSize: 18,
                        fontWeight: FontWeight.bold,
                        color: Colors.black54))
              ]),
        )
      ],
    );
  }
}

class WaitForVemasIndicator extends StatelessWidget {
  const WaitForVemasIndicator({
    Key key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Center(
        child: Container(
            decoration: BoxDecoration(
              border: Border.all(
                color: Colors.grey,
                width: 2,
              ),
              borderRadius: BorderRadius.circular(5),
            ),
            margin: const EdgeInsets.all(8),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                Text("Daten werden geladen..."),
                Padding(
                    padding: EdgeInsets.all(16.0),
                    child: CircularProgressIndicator()),
              ],
            )));
  }
}

class FreeSlot extends StatelessWidget {
  String freeSlot;

  FreeSlot(this.freeSlot);

  @override
  Widget build(BuildContext context) {
    return Center(
        child: Container(
            decoration: BoxDecoration(
              border: Border.all(
                color: Color.fromRGBO(202, 212, 0, 1.0),
                width: 2,
              ),
              borderRadius: BorderRadius.circular(5),
            ),
            margin: const EdgeInsets.all(8),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                Padding(padding: EdgeInsets.all(16.0), child: icon()),
                Text(freeSlot, style: boldText),
              ],
            )));
  }

  static Stack icon() {
    return Stack(
      children: <Widget>[
        Icon(Icons.calendar_today),
        Transform.scale(scale: 0.6, child: Icon(Icons.done))
      ],
    );
  }
}

class AppErrorWidget extends StatelessWidget {
  final String errorMessage;

  const AppErrorWidget(
    this.errorMessage, {
    Key key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Center(
        child: Container(
            decoration: BoxDecoration(
              border: Border.all(
                color: Colors.orange,
                width: 4,
              ),
              borderRadius: BorderRadius.circular(5),
            ),
            margin: const EdgeInsets.all(8),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: <Widget>[
                    Padding(
                        padding: EdgeInsets.all(16.0),
                        child: Icon(Icons.error_outline)),
                    Text("Ups es ist ein Fehler passiert", style: boldText)
                  ],
                ),
                Text(
                  errorMessage,
                  style: smallText,
                )
              ],
            )));
  }
}

class ButtonDY extends StatelessWidget {
  String text;
  Function onPressedFunction;
  Color color = null;

  ButtonDY({this.text, this.onPressedFunction, this.color});

  @override
  Widget build(BuildContext context) {
    return RaisedButton(
        onPressed: () {
          if (onPressedFunction != null) {
            onPressedFunction.call();
          }
        },
        color: color != null ? color : Color.fromRGBO(202, 212, 0, 1.0),
        child: Text(text != null ? text : "ButtonDY",
            style: TextStyle(color: Colors.white)),
        shape: RoundedRectangleBorder(
            borderRadius: new BorderRadius.circular(30.0)));
  }
}

final boldText = TextStyle(
  color: Colors.black,
  fontWeight: FontWeight.w800,
  fontFamily: 'Roboto',
  //letterSpacing: 0.5,
  fontSize: 18,
  //height: 2,
);

final smallText = TextStyle(
  color: Colors.black,
  fontWeight: FontWeight.w400,
  fontFamily: 'Roboto',
  //letterSpacing: 0.5,
  fontSize: 12,
  //height: 2,
);

final tinyText = TextStyle(
  color: Colors.black,
  fontWeight: FontWeight.w400,
  fontFamily: 'Roboto',
  //letterSpacing: 0.5,
  fontSize: 10,
  //height: 2,
);

class GUISnippets {
  static Divider defaultDivider() {
    return const Divider(
      color: Colors.black12,
      height: 5,
      thickness: 1,
      indent: 20,
      endIndent: 20,
    );
  }
}

class ResponsiveWidget {
  //Large screen is any screen whose width is more than 1200 pixels
  static bool isLargeScreen(BuildContext context) {
    return MediaQuery.of(context).orientation == Orientation.landscape;
  }

//Small screen is any screen whose width is less than 800 pixels
  static bool isSmallScreen(BuildContext context) {
    return MediaQuery.of(context).orientation == Orientation.portrait;
  }
}
